# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-04-13 11:25
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Testimonial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField()),
                ('author', models.CharField(max_length=100)),
                ('affiliation', models.CharField(blank=True, max_length=100)),
                ('added', models.DateTimeField(default=django.utils.timezone.now)),
                ('active', models.BooleanField(default=False)),
            ],
        ),
    ]
